@@ -197,7 +197,7 @@ A compound field that uses inflate/deflate convert input from multiple subfields
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
