@@ -47,7 +47,7 @@ L<Rose::HTML::Form::Field::DateTime::StartDate> is a subclass of L<Rose::HTML::F
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
