@@ -265,7 +265,7 @@ With arguments, it will get or set the label for the option whose value is VALUE
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
