@@ -321,7 +321,7 @@ Returns an array (in list context) or reference to an array (in scalar context)
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
