@@ -10,7 +10,7 @@ use Rose::HTML::Object::Message::Localizer;
 use Rose::HTML::Object::Localized;
 our @ISA = qw(Rose::HTML::Object::Localized);
 
-our $VERSION = '0.541';
+our $VERSION = '0.549';
 
 our $Debug = undef;
 
@@ -279,6 +279,9 @@ sub html_attr_hook
 
 sub delete_html_attr_hook { shift->html_attr_hook($_[0] => undef) }
 
+sub set_error   { shift->error('')    }
+sub unset_error { shift->error(undef) }
+
 sub html_error
 {
   my($self) = shift;
@@ -321,7 +324,7 @@ sub html_errors
     return $code->($self);
   }
 
-  my $error = join(', ', $self->errors);
+  my $error = join(', ', grep { /\S/ } $self->errors);
 
   if($error)
   {
@@ -1051,6 +1054,14 @@ If the L<escape_html|/escape_html> flag is set to true (the default), then the e
 
 Serializes the object as an HTML tag.  In other words, it is the concatenation of the strings returned by L<html_element()|/html_element> and L<html_attrs_string()|/html_attrs_string>, wrapped with the appropriate angled brackets.
 
+=item B<set_error>
+
+Set the L<error|/error> to a defined but "invisible" (zero-length) value.  This value will not be displayed by the L<html_error|/html_error> or L<xhtml_error|/xhtml_error>.  Use this method when you want to flag a field as having an error, but don't want a visible error message.
+
+=item B<unset_error>
+
+Set the L<error|/error> to a undef.
+
 =item B<validate_html_attrs BOOL>
 
 If set to true, HTML attribute arguments to C<html_attr> and C<html_attr_hook> will be validated by calling C<html_attr_is_valid(ATTR)>, where ATTR is the name of the attribute being set or read.  The default value is true.
@@ -1103,7 +1114,7 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-HTML-Objects>
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
