@@ -3,7 +3,7 @@ package Rose::HTML::Objects;
 use strict;
 
 # The sole purpose of this module is to provide a version number
-our $VERSION = '0.548';
+our $VERSION = '0.549';
 
 1;
 
@@ -63,11 +63,11 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-HTML-Objects>
 
 =head1 CONTRIBUTORS
 
-Uwe Voelker, Jacques Supcik, Cees Hek
+Uwe Voelker, Jacques Supcik, Cees Hek, Denis Moskowitz 
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
